package cn.com.infosec.x509;

import cn.com.infosec.x509.util.StreamParser;
import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.security.NoSuchAlgorithmException;
import java.security.Provider;
import java.util.Collection;

public class X509StreamParser implements StreamParser {
   private Provider _provider;
   private X509StreamParserSpi _spi;

   public static X509StreamParser getInstance(String type) {
      try {
         return createParser(X509Util.getImplementation("X509StreamParser", type));
      } catch (NoSuchAlgorithmException var1) {
         throw new NoSuchParserException(var1.getMessage());
      }
   }

   public static X509StreamParser getInstance(String type, String provider) {
      return getInstance(type, X509Util.getProvider(provider));
   }

   public static X509StreamParser getInstance(String type, Provider provider) {
      try {
         return createParser(X509Util.getImplementation("X509StreamParser", type, provider));
      } catch (NoSuchAlgorithmException var2) {
         throw new NoSuchParserException(var2.getMessage());
      }
   }

   private static X509StreamParser createParser(X509Util.Implementation impl) {
      X509StreamParserSpi var1 = (X509StreamParserSpi)impl.getEngine();
      return new X509StreamParser(impl.getProvider(), var1);
   }

   private X509StreamParser(Provider provider, X509StreamParserSpi spi) {
      this._provider = provider;
      this._spi = spi;
   }

   public Provider getProvider() {
      return this._provider;
   }

   public void init(InputStream stream) {
      this._spi.engineInit(stream);
   }

   public void init(byte[] data) {
      this._spi.engineInit(new ByteArrayInputStream(data));
   }

   public Object read() {
      return this._spi.engineRead();
   }

   public Collection readAll() {
      return this._spi.engineReadAll();
   }
}
